@@ -1,4 +1,11 @@
 import json
+import logging
+import sys
+
+LOG_FORMAT = (
+    "%(levelname) -4s %(asctime)s %(funcName) "
+    "-3s %(lineno) -5d: %(message)s"
+)
 
 
 class Mythic:
@@ -12,9 +19,10 @@ class Mythic:
         server_ip: str = None,
         ssl: bool = False,
         server_port: int = None,
-        server_api_version: float = 1.4,
         global_timeout: int = None,
         schema: str = None,
+        log_level: int = logging.WARNING,
+        log_format: str = LOG_FORMAT,
     ):
         self.username = username
         self.password = password
@@ -23,16 +31,20 @@ class Mythic:
         self.refresh_token = refresh_token
         self.server_ip = server_ip
         self.server_port = server_port
-        self.server_api_version = server_api_version
         self.ssl = ssl
         self.http = "http://" if not ssl else "https://"
         self.ws = "ws://" if not ssl else "wss://"
         self.global_timeout = global_timeout if global_timeout is not None else -1
-        self.scripting_version = 3
+        self.scripting_version = "0.2.7"
         self.current_operation_id = 0
-        self.operator_id = None
-        self.operator = None
         self.schema = schema
+        self.log_level = log_level
+        self.log_handler = logging.StreamHandler(sys.stdout)
+        self.logger = logging.getLogger("mythic")
+        self.logger.setLevel(self.log_level)
+        self.log_handler.setLevel(self.log_level)
+        self.log_handler.setFormatter(logging.Formatter(log_format))
+        self.logger.addHandler(self.log_handler)
 
     def __str__(self):
         return json.dumps(
@@ -46,8 +58,6 @@ class Mythic:
                 "server_port": self.server_port,
                 "ssl": self.ssl,
                 "current_operation_id": self.current_operation_id,
-                "operator": self.operator,
-                "operator_id": self.operator_id,
             },
             indent=4,
         )
