@@ -6,6 +6,7 @@ from time import time
 from typing import AsyncGenerator, TypeVar
 
 import aiohttp
+import graphql.language.ast
 from gql import Client, gql
 from gql.transport.aiohttp import AIOHTTPTransport
 from gql.transport.websockets import WebsocketsTransport
@@ -17,10 +18,11 @@ T = TypeVar("T")
 
 
 async def timeout_generator(
-    it: AsyncGenerator[T, None], timeout: float = None
+        mythic: mythic_classes.Mythic, it: AsyncGenerator[T, None], timeout: float = None
 ) -> AsyncGenerator[T, None]:
     start = time()
     should_timeout = timeout is not None and timeout > 0
+    task = None
     while True:
         # we don't want to wait for timeout each time, that's an overall timeout
         if should_timeout:
@@ -35,12 +37,16 @@ async def timeout_generator(
             task = asyncio.create_task(it.__anext__())
             yield await asyncio.wait_for(task, new_timeout)
         except asyncio.TimeoutError:
-            logging.info("Timeout reached in timeout_generator")
-            task.cancel()
-            return
+            if task is not None:
+                task.cancel()
+            raise asyncio.TimeoutError
         except StopAsyncIteration:
-            return
+            if task is not None:
+                task.cancel()
+            raise asyncio.TimeoutError
         except Exception as e:
+            if task is not None:
+                task.cancel()
             raise e
 
 
@@ -68,7 +74,7 @@ async def get_ws_transport(mythic: mythic_classes.Mythic) -> WebsocketsTransport
     websocket_transport = WebsocketsTransport(
         url=f"{mythic.ws}{mythic.server_ip}:{mythic.server_port}/graphql/",
         headers=get_headers(mythic),
-        ssl=ssl_context,
+        ssl=ssl_context if mythic.ssl else False,
     )
     return websocket_transport
 
@@ -127,6 +133,14 @@ async def http_get_chunked(
         raise e
 
 
+async def get_operation_name(graphql_data: graphql.language.ast.DocumentNode) -> str:
+    #print(graphql_data.to_dict())
+    if len(graphql_data.definitions) > 0:
+        #print(graphql_data.definitions[0].name.value)
+        return graphql_data.definitions[0].name.value
+    return ""
+
+
 async def graphql_post(
     mythic: mythic_classes.Mythic,
     gql_query: gql = None,
@@ -137,12 +151,14 @@ async def graphql_post(
         query_data = gql(query) if query is not None else gql_query
         if query_data is None:
             raise Exception("No data or gql_data passed into graphql_post function")
+        operation_name = await get_operation_name(query_data)
         async with Client(
             transport=await get_http_transport(mythic=mythic),
             fetch_schema_from_transport=False,
+            execute_timeout=None if mythic.global_timeout < 0 else mythic.global_timeout,
             schema=mythic.schema,
         ) as session:
-            result = await session.execute(query_data, variable_values=variables)
+            result = await session.execute(query_data, variable_values=variables, operation_name=operation_name)
             return result
     except Exception as e:
         raise e
@@ -165,19 +181,19 @@ async def graphql_subscription(
             raise Exception(
                 "No data or gql_data passed into graphql_subscription function"
             )
-
+        operation_name = await get_operation_name(query_data)
         async with Client(
             transport=await get_ws_transport(mythic=mythic),
             fetch_schema_from_transport=False,
+            execute_timeout=None,
         ) as session:
-            logging.debug(f"Started subscription for {query}")
             async for result in timeout_generator(
-                it=session.subscribe(query_data, variable_values=variables),
+                mythic=mythic,
+                it=session.subscribe(query_data, variable_values=variables, operation_name=operation_name),
                 timeout=local_timeout,
             ):
                 yield result
     except Exception as e:
-        print("got exception in graphql_subscription")
         raise e
 
 
@@ -202,10 +218,10 @@ async def load_mythic_schema(mythic: mythic_classes.Mythic) -> bool:
                 mythic.schema = schema
             return True
         except Exception as e:
-            logging.error(
+            mythic.logger.error(
                 f"[-] Found mythic_schema.graphql locally, but failed to read it:\n{str(e)}"
             )
-            logging.error(
+            mythic.logger.error(
                 "[-] Unable to verify GraphQL queries syntactically before executing"
             )
             return False
@@ -213,7 +229,7 @@ async def load_mythic_schema(mythic: mythic_classes.Mythic) -> bool:
         try:
             schema = await fetch_graphql_schema(mythic)
         except Exception as e:
-            logging.error(f"[-] Failed to contact Mythic and fetch schema:\n{str(e)}")
+            mythic.logger.error(f"[-] Failed to contact Mythic and fetch schema:\n{str(e)}")
             return False
         try:
             mythic.schema = schema
@@ -221,8 +237,8 @@ async def load_mythic_schema(mythic: mythic_classes.Mythic) -> bool:
                 f.write(schema)
             return True
         except Exception as e:
-            logging.error(f"[-] Failed to save Mythic schema to disk:\n{str(e)}")
-            logging.error(
+            mythic.logger.error(f"[-] Failed to save Mythic schema to disk:\n{str(e)}")
+            mythic.logger.error(
                 "[-] Unable to verify GraphQL queries syntactically before executing"
             )
-            return False
+            return False
\ No newline at end of file
